Fun_MAE_to_taskFunc: Convert MAE to mlr task

Description Usage Arguments Details Value Examples

Description

Convert MAE to mlr task

Usage

1
2
Fun_MAE_to_taskFunc(MAE_obj, param.Y.name, param.covariates,
  param_positive_y_level, task_type)

Arguments

MAE_obj

MAE class

param.Y.name

Vector of dependent variable name

param.covariates

Vector of coaraiate variable(s) name

param_positive_y_level

if ClassifTask, value (character or numeric) to be considered as the positive factor outcome

Details

In case of individual MAE assay (omic) with multiple sub-assays, only first sub-assay will be used. MAE's helpers functions longFormat and wideFormat may not be best candidates, since mlr's functional data require complete subject structure for all 'assays' ('functionals'). this can be achieved by either removing non-complete subjects, or by creating dummy entities with NA. (which can later be imputed if required).

Either ClassifTask or RegrTask will be returned, based on the type of the param.Y.name variable

Value

mlr's ClassifTask or RegrTask

Examples

1
2
3
data(miniACC, package = 'MultiAssayExperiment') # ExpressionSet
miniACC
Fun_MAE_to_taskFunc(miniACC, param.Y.name = 'vital_status', param.covariates = c('gender','days_to_death'), param_positive_y_level = '1')

drorberel/Bioc2mlr documentation built on May 16, 2019, 5 a.m.