Description Usage Arguments Details Value Examples
Convert SE to mlr task
1 2 | Fun_SE_to_taskFunc(SE_obj, param.Y.name, param.covariates,
param_positive_y_level, task_return_format, task_type)
|
SE_obj |
SE class |
param.Y.name |
Vector of dependent variable name |
param.covariates |
Vector of coaraiate variable(s) name |
param_positive_y_level |
if ClassifTask, value (character or numeric) to be considered as the positive factor outcome |
SE with multiple sub-assays, will include each sub-assay separately.
Either ClassifTask or RegrTask will be returned, based on the type of the param.Y.name variable
mlr's ClassifTask or RegrTask
1 2 3 | data(airway, package="airway") # RangedSummarizedExperiment
airway
Fun_SE_to_taskFunc(airway, param.Y.name = 'dex', param.covariates = c('avgLength'), param_positive_y_level = 'trt')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.