Description Usage Arguments Details Value Examples
Convert MAE to mlr task
1 2 | Fun_MAE_to_taskFunc(MAE_obj, param.Y.name, param.covariates,
param_positive_y_level, task_type)
|
MAE_obj |
MAE class |
param.Y.name |
Vector of dependent variable name |
param.covariates |
Vector of coaraiate variable(s) name |
param_positive_y_level |
if ClassifTask, value (character or numeric) to be considered as the positive factor outcome |
In case of individual MAE assay (omic) with multiple sub-assays, only first sub-assay will be used. MAE's helpers functions longFormat and wideFormat may not be best candidates, since mlr's functional data require complete subject structure for all 'assays' ('functionals'). this can be achieved by either removing non-complete subjects, or by creating dummy entities with NA. (which can later be imputed if required).
Either ClassifTask or RegrTask will be returned, based on the type of the param.Y.name variable
mlr's ClassifTask or RegrTask
1 2 3 | data(miniACC, package = 'MultiAssayExperiment') # ExpressionSet
miniACC
Fun_MAE_to_taskFunc(miniACC, param.Y.name = 'vital_status', param.covariates = c('gender','days_to_death'), param_positive_y_level = '1')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.